@@ -1,4 +1,4 @@
-def error_response(status, message):
+def error_response(status:str, message:str):
     """
     Custom error response
 
@@ -17,7 +17,7 @@ def error_response(status, message):
     return payload
 
 
-def success_response(status, message, data):
+def success_response(status:str, message:str, data:dict):
     """
     Custom success response
 
